==> jc-1.4.0.tar.gz: java/security/cert/PKIXBuilderParameters.h <==
// public class java.security.cert.PKIXBuilderParameters

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d3cb8944017d9c9 java_security_cert_PKIXBuilderParameters
// @dep_class a8772e192e80ffa9 java_security_cert_PKIXParameters

// header file dependencies
// @dep_header java_security_cert_PKIXParameters

#include "java/security/cert/PKIXParameters.h"

#ifndef _JC_java_security_cert_PKIXBuilderParameters_H_
#define _JC_java_security_cert_PKIXBuilderParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyStore$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXBuilderParameters$sub_refs	_jc_java_security_cert_PKIXBuilderParameters$sub_refs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs	_jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$refs	_jc_java_security_cert_PKIXBuilderParameters$refs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$nonrefs	_jc_java_security_cert_PKIXBuilderParameters$nonrefs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$object	_jc_java_security_cert_PKIXBuilderParameters$object;

typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vmethods	_jc_java_security_cert_PKIXBuilderParameters$vmethods;
typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vtable	_jc_java_security_cert_PKIXBuilderParameters$vtable;
typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vtype	_jc_java_security_cert_PKIXBuilderParameters$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXBuilderParameters$method$_init$7cb7035a6ee2eab4(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, struct _jc_java_security_KeyStore$object *, struct _jc_object *);
extern void _jc_java_security_cert_PKIXBuilderParameters$method$_init$fbe51447507c723a(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jint _jc_java_security_cert_PKIXBuilderParameters$method$getMaxPathLength$bf0d8fc601d75b51(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *);
extern void _jc_java_security_cert_PKIXBuilderParameters$method$setMaxPathLength$8ac7523169fdd03b(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, jint);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXBuilderParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$getMaxPathLength$bf0d8fc601d75b51;
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$setMaxPathLength$8ac7523169fdd03b;
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXBuilderParameters$vmethods {
	jint	(*getMaxPathLength$bf0d8fc601d75b51)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *);
	void	(*setMaxPathLength$8ac7523169fdd03b)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *);
};

// Vtable
struct _jc_java_security_cert_PKIXBuilderParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXParameters$vmethods	java_security_cert_PKIXParameters;
	_jc_java_security_cert_PKIXBuilderParameters$vmethods	java_security_cert_PKIXBuilderParameters;
};

// Vtype
struct _jc_java_security_cert_PKIXBuilderParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXBuilderParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXBuilderParameters$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXBuilderParameters$refs {
    _jc_java_security_cert_PKIXBuilderParameters$sub_refs	java_security_cert_PKIXBuilderParameters;
    _jc_java_security_cert_PKIXParameters$sub_refs	java_security_cert_PKIXParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs {
	jint	maxPathLength;
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXBuilderParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXParameters$sub_nonrefs	java_security_cert_PKIXParameters;
    _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs	java_security_cert_PKIXBuilderParameters;
};

// Object instance structure
struct _jc_java_security_cert_PKIXBuilderParameters$object {
	_jc_java_security_cert_PKIXBuilderParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXBuilderParameters$vtype	*vtype;
	_jc_java_security_cert_PKIXBuilderParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXBuilderParameters$vtype _jc_java_security_cert_PKIXBuilderParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXBuilderParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXBuilderParameters$class_object;

#endif	/* _JC_java_security_cert_PKIXBuilderParameters_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/PKIXBuilderParameters.h <==
// public class java.security.cert.PKIXBuilderParameters

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d3cb8944017d9c9 java_security_cert_PKIXBuilderParameters
// @dep_class a8772e192e80ffa9 java_security_cert_PKIXParameters

// header file dependencies
// @dep_header java_security_cert_PKIXParameters

#include "java/security/cert/PKIXParameters.h"

#ifndef _JC_java_security_cert_PKIXBuilderParameters_H_
#define _JC_java_security_cert_PKIXBuilderParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyStore$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXBuilderParameters$sub_refs	_jc_java_security_cert_PKIXBuilderParameters$sub_refs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs	_jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$refs	_jc_java_security_cert_PKIXBuilderParameters$refs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$nonrefs	_jc_java_security_cert_PKIXBuilderParameters$nonrefs;
typedef struct _jc_java_security_cert_PKIXBuilderParameters$object	_jc_java_security_cert_PKIXBuilderParameters$object;

typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vmethods	_jc_java_security_cert_PKIXBuilderParameters$vmethods;
typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vtable	_jc_java_security_cert_PKIXBuilderParameters$vtable;
typedef const struct _jc_java_security_cert_PKIXBuilderParameters$vtype	_jc_java_security_cert_PKIXBuilderParameters$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXBuilderParameters$method$_init$7cb7035a6ee2eab4(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, struct _jc_java_security_KeyStore$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_PKIXBuilderParameters$method$_init$fbe51447507c723a(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_security_cert_PKIXBuilderParameters$method$getMaxPathLength$bf0d8fc601d75b51(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_PKIXBuilderParameters$method$setMaxPathLength$8ac7523169fdd03b(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXBuilderParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$getMaxPathLength$bf0d8fc601d75b51;
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$setMaxPathLength$8ac7523169fdd03b;
extern _jc_method _jc_java_security_cert_PKIXBuilderParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXBuilderParameters$vmethods {
	jint	(*getMaxPathLength$bf0d8fc601d75b51)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *) _JC_JCNI_ATTR;
	void	(*setMaxPathLength$8ac7523169fdd03b)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXBuilderParameters$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_PKIXBuilderParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXParameters$vmethods	java_security_cert_PKIXParameters;
	_jc_java_security_cert_PKIXBuilderParameters$vmethods	java_security_cert_PKIXBuilderParameters;
};

// Vtype
struct _jc_java_security_cert_PKIXBuilderParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXBuilderParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXBuilderParameters$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXBuilderParameters$refs {
    _jc_java_security_cert_PKIXBuilderParameters$sub_refs	java_security_cert_PKIXBuilderParameters;
    _jc_java_security_cert_PKIXParameters$sub_refs	java_security_cert_PKIXParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs {
	jint	maxPathLength;
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXBuilderParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXParameters$sub_nonrefs	java_security_cert_PKIXParameters;
    _jc_java_security_cert_PKIXBuilderParameters$sub_nonrefs	java_security_cert_PKIXBuilderParameters;
};

// Object instance structure
struct _jc_java_security_cert_PKIXBuilderParameters$object {
	_jc_java_security_cert_PKIXBuilderParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXBuilderParameters$vtype	*vtype;
	_jc_java_security_cert_PKIXBuilderParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXBuilderParameters$vtype _jc_java_security_cert_PKIXBuilderParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXBuilderParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXBuilderParameters$class_object;

#endif	/* _JC_java_security_cert_PKIXBuilderParameters_H_ */
